// #include <MQ135.h>
// #include <OneWire.h>
// #include <DallasTemperature.h>

// // Sets pins on Arduino for batch temperature sensor and gas sensor
// #define PIN_MQ135 A0
// #define batchTemp 7

// MQ135 mq135_sensor(PIN_MQ135);
// OneWire ds18x20[] = { batchTemp };
// const int oneWireCount = sizeof(ds18x20) / sizeof(OneWire);
// DallasTemperature sensor[oneWireCount];

// // Change temperature and humidity according to room temperature and % humidity
// float temperature = 24.1;  // Degrees celcius
// float humidity = 77.0; // % Humidity

// void setup() {
//   Serial.begin(9600);
//   Serial.println("MQ135 temperature sensor ready");
//   Serial.println("Temperature, correctedRZero, correctedPPM");

//   DeviceAddress deviceAddress;
//   for (int i = 0; i < oneWireCount; i++) {
//     sensor[i].setOneWire(&ds18x20[i]);
//     sensor[i].begin();
//     if (sensor[i].getAddress(deviceAddress, 0)) sensor[i].setResolution(deviceAddress, 12);
//   }
// }

// void loop() {
//   for (int i = 0; i < oneWireCount; i++) {
//     sensor[i].requestTemperatures();
//   }

//   // float correctedRZero = mq135_sensor.getCorrectedRZero(temperature, humidity);
//   // float correctedPPM = mq135_sensor.getCorrectedPPM(temperature, humidity);
//     float correctedRZero =1;
//     float correctedPPM = 1;


//   for (int i = 0; i < oneWireCount; i++) {
//     float temperature = sensor[i].getTempFByIndex(0);
//     Serial.print(temperature);
//     Serial.print(",");

//     Serial.print(correctedRZero);
//     Serial.print(",");
//     Serial.println(correctedPPM);
//     delay(500);
//   }
// }



#include <MQ135.h>
#include <OneWire.h>
#include <DallasTemperature.h>

// Sets pins on Arduino for batch temperature sensor and gas sensor
#define PIN_MQ135 A0
#define batchTemp 7

MQ135 mq135_sensor(PIN_MQ135);
OneWire ds18x20[] = { batchTemp };
const int oneWireCount = sizeof(ds18x20) / sizeof(OneWire);
DallasTemperature sensor[oneWireCount];

// Change temperature and humidity according to room temperature and % humidity
float temperature = 24.1;  // Degrees Celsius
float humidity = 77.0; // % Humidity

void setup() {
  Serial.begin(9600);
  Serial.println("MQ135 temperature sensor ready");
  Serial.println("Time (s), Temperature, Corrected RZero, Corrected PPM");

  DeviceAddress deviceAddress;
  for (int i = 0; i < oneWireCount; i++) {
    sensor[i].setOneWire(&ds18x20[i]);
    sensor[i].begin();
    if (sensor[i].getAddress(deviceAddress, 0)) sensor[i].setResolution(deviceAddress, 12);
  }
}

void loop() {
  // Calculate the elapsed time in seconds
  unsigned long elapsedMillis = millis();
  float elapsedMinutes = elapsedMillis / 1000.0 / 60; // Convert milliseconds to mins

  for (int i = 0; i < oneWireCount; i++) {
    sensor[i].requestTemperatures();
  }

  float correctedRZero = mq135_sensor.getCorrectedRZero(temperature, humidity);
  float correctedPPM = mq135_sensor.getCorrectedPPM(temperature, humidity);

  for (int i = 0; i < oneWireCount; i++) {
    float temperature = sensor[i].getTempFByIndex(0);
    
    // Print elapsed time in minutes
    Serial.print(elapsedMinutes);
    Serial.print(",");
    
    Serial.print(temperature);
    Serial.print(",");

    Serial.print(correctedRZero);
    Serial.print(",");
    
    Serial.println(correctedPPM);
    delay(230);
  }
}

